datastructuretools.TypedCollection
==================================

.. abjad-lineage:: abjad.tools.datastructuretools.TypedCollection.TypedCollection

.. autoclass:: abjad.tools.datastructuretools.TypedCollection.TypedCollection

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.item_class
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.items
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__contains__
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__eq__
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__format__
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__hash__
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__iter__
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__len__
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__ne__
      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.item_class
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.items
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCollection.TypedCollection.__repr__
   :noindex:
